@@ -1,5 +1,7 @@
+import json
+
 import grpc
-from .gRPC_proto.user_proto import user_pb2, user_pb2_grpc, auth_pb2_grpc, auth_pb2
+from gRPC_proto.user import user_pb2, user_pb2_grpc, auth_pb2_grpc, auth_pb2
 
 
 class User:
@@ -28,7 +30,7 @@ class User:
     def login(self):
         try:
             response = self.auth_stub.Login(auth_pb2.LoginRequest(username=self.username, password=self.password))
-            meta = [('access_token', response.token)]
+            meta = [('access_token', json.loads(response.token)['token'])]
             return meta
         except grpc.RpcError as e:
             raise Exception('Error ' + str(e.code()) + ': ' + str(e.details()))
